@@ -80,7 +80,7 @@ cnc_weak_cb (gpointer user_data, GObject *object)
 static void
 impl_Client_notifyAction (PortableServer_Servant servant,
 			  GNOME_Database_ActionId action,
-			  GNOME_Database_ParameterList *corba_params,
+			  Bonobo_PropertySet *corba_params,
 			  CORBA_Environment *ev)
 {
 }
@@ -145,9 +145,7 @@ gda_client_finalize (GObject *object)
 	g_return_if_fail (GDA_IS_CLIENT (client));
 
 	/* free memory */
-	g_list_foreach (client->priv->connections, (GFunc) gda_connection_close, NULL);
-	g_list_free (client->priv->connections);
-	client->priv->connections = NULL;
+	gda_client_close_all_connections (client);
 
 	g_hash_table_foreach (client->priv->providers, (GHFunc) free_hash_provider, NULL);
 	g_hash_table_destroy (client->priv->providers);
@@ -331,3 +329,16 @@ gda_client_find_connection (GdaClient *client,
 
 	return NULL;
 }
+
+/**
+ * gda_client_close_all_connections
+ */
+void
+gda_client_close_all_connections (GdaClient *client)
+{
+	g_return_if_fail (GDA_IS_CLIENT (client));
+
+	g_list_foreach (client->priv->connections, (GFunc) g_object_unref, NULL);
+	g_list_free (client->priv->connections);
+	client->priv->connections = NULL;
+}
