@@ -97,8 +97,10 @@ typedef struct {
 	GList *gda_params;
 } GdaProviderInfo;
 
-GList *gda_config_get_provider_list (void);
-void   gda_config_free_provider_list (GList *list);
+GList           *gda_config_get_provider_list (void);
+void             gda_config_free_provider_list (GList *list);
+GdaProviderInfo *gda_config_get_provider_by_name (const gchar *name);
+void             gda_config_free_provider_info (GdaProviderInfo *provider_info);
 
 /*
  * Data sources configuration
@@ -123,6 +125,15 @@ void               gda_config_save_data_source (const gchar *name,
 						const gchar *cnc_string,
 						const gchar *description,
 						const gchar *username);
+void               gda_config_remove_data_source (const gchar *name);
+
+/*
+ * GDA configuration sections/keys
+ */
+#define GDA_CONFIG_SECTION_DATASOURCES       "/apps/libgda/Datasources"
+#define GDA_CONFIG_SECTION_LAST_CONNECTIONS  "/apps/libgda/LastConnections"
+
+#define GDA_CONFIG_KEY_MAX_LAST_CONNECTIONS  "/apps/libgda/MaxLastConnections"
 
 G_END_DECLS
 
