@@ -1,5 +1,5 @@
 /* GDA common library
- * Copyright (C) 1998-2001 The Free Software Foundation
+ * Copyright (C) 1998-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -23,6 +23,7 @@
 #if !defined(__gda_data_model_h__)
 #  define __gda_data_model_h__
 
+#include <libgda/gda-row.h>
 #include <libgda/gda-value.h>
 
 G_BEGIN_DECLS
@@ -51,20 +52,26 @@ struct _GdaDataModelClass {
 	/* virtual methods */
 	gint (* get_n_rows) (GdaDataModel *model);
 	gint (* get_n_columns) (GdaDataModel *model);
+	GdaFieldAttributes * (* describe_column) (GdaDataModel *model, gint col);
 	const GdaValue * (* get_value_at) (GdaDataModel *model, gint col, gint row);
 };
 
-GType           gda_data_model_get_type (void);
+GType               gda_data_model_get_type (void);
 
-void            gda_data_model_changed (GdaDataModel *model);
-void            gda_data_model_freeze (GdaDataModel *model);
-void            gda_data_model_thaw (GdaDataModel *model);
+void                gda_data_model_changed (GdaDataModel *model);
+void                gda_data_model_freeze (GdaDataModel *model);
+void                gda_data_model_thaw (GdaDataModel *model);
 
-gint            gda_data_model_get_n_rows (GdaDataModel *model);
-gint            gda_data_model_get_n_columns (GdaDataModel *model);
-const gchar    *gda_data_model_get_column_title (GdaDataModel *model, gint col);
-void            gda_data_model_set_column_title (GdaDataModel *model, gint col, const gchar *title);
-const GdaValue *gda_data_model_get_value_at (GdaDataModel *model, gint col, gint row);
+gint                gda_data_model_get_n_rows (GdaDataModel *model);
+gint                gda_data_model_get_n_columns (GdaDataModel *model);
+GdaFieldAttributes *gda_data_model_describe_column (GdaDataModel *model, gint col);
+const gchar        *gda_data_model_get_column_title (GdaDataModel *model, gint col);
+void                gda_data_model_set_column_title (GdaDataModel *model, gint col, const gchar *title);
+const GdaValue     *gda_data_model_get_value_at (GdaDataModel *model, gint col, gint row);
+
+gchar              *gda_data_model_to_comma_separated (GdaDataModel *model);
+gchar              *gda_data_model_to_tab_separated (GdaDataModel *model);
+gchar              *gda_data_model_to_xml (GdaDataModel *model, gboolean standalone);
 
 G_END_DECLS
 
