@@ -31,12 +31,14 @@ G_BEGIN_DECLS
 
 #define TIMEZONE_INVALID (2*12*60*60)
 
-typedef CORBA_any      GdaValue;
-typedef CORBA_TypeCode GdaValueType;
+typedef CORBA_any                     GdaValue;
+typedef GNOME_Database_ValueList      GdaValueList;
+typedef CORBA_TypeCode                GdaValueType;
+typedef GNOME_Database_Date           GdaDate;
 typedef GNOME_Database_GeometricPoint GdaGeometricPoint;
-typedef GNOME_Database_Date GdaDate;
-typedef GNOME_Database_Time GdaTime;
-typedef GNOME_Database_Timestamp GdaTimestamp;
+typedef GNOME_Database_Numeric        GdaNumeric;
+typedef GNOME_Database_Time           GdaTime;
+typedef GNOME_Database_Timestamp      GdaTimestamp;
 
 #define GDA_VALUE_TYPE_NULL      TC_null
 #define GDA_VALUE_TYPE_BIGINT    TC_CORBA_long_long
@@ -46,6 +48,8 @@ typedef GNOME_Database_Timestamp GdaTimestamp;
 #define GDA_VALUE_TYPE_DOUBLE    TC_CORBA_double
 #define GDA_VALUE_TYPE_GEOMETRIC_POINT     TC_GNOME_Database_GeometricPoint
 #define GDA_VALUE_TYPE_INTEGER   TC_CORBA_long
+#define GDA_VALUE_TYPE_LIST      TC_GNOME_Database_ValueList
+#define GDA_VALUE_TYPE_NUMERIC   TC_GNOME_Database_Numeric
 #define GDA_VALUE_TYPE_SINGLE    TC_CORBA_float
 #define GDA_VALUE_TYPE_SMALLINT  TC_CORBA_short
 #define GDA_VALUE_TYPE_STRING    TC_CORBA_string
@@ -54,18 +58,20 @@ typedef GNOME_Database_Timestamp GdaTimestamp;
 #define GDA_VALUE_TYPE_TINYINT   TC_CORBA_char
 
 GdaValue     *gda_value_new_null (void);
-GdaValue     *gda_value_new_bigint (long long val);
+GdaValue     *gda_value_new_bigint (gint64 val);
 GdaValue     *gda_value_new_binary (gconstpointer val);
 GdaValue     *gda_value_new_boolean (gboolean val);
-GdaValue     *gda_value_new_date (GdaDate *val);
+GdaValue     *gda_value_new_date (const GdaDate *val);
 GdaValue     *gda_value_new_double (gdouble val);
-GdaValue     *gda_value_new_geometric_point (GdaGeometricPoint *val);
+GdaValue     *gda_value_new_geometric_point (const GdaGeometricPoint *val);
 GdaValue     *gda_value_new_integer (gint val);
+GdaValue     *gda_value_new_list (const GdaValueList *val);
+GdaValue     *gda_value_new_numeric (const GdaNumeric *val);
 GdaValue     *gda_value_new_single (gfloat val);
 GdaValue     *gda_value_new_smallint (gshort val);
 GdaValue     *gda_value_new_string (const gchar *val);
-GdaValue     *gda_value_new_time (GdaTime *val);
-GdaValue     *gda_value_new_timestamp (GdaTimestamp *val);
+GdaValue     *gda_value_new_time (const GdaTime *val);
+GdaValue     *gda_value_new_timestamp (const GdaTimestamp *val);
 GdaValue     *gda_value_new_tinyint (gchar val);
 
 void          gda_value_free (GdaValue *value);
@@ -74,8 +80,8 @@ gboolean      gda_value_isa (const GdaValue *value, GdaValueType type);
 gboolean      gda_value_is_null (GdaValue *value);
 GdaValue     *gda_value_copy (GdaValue *value);
 
-long long     gda_value_get_bigint (GdaValue *value);
-void          gda_value_set_bigint (GdaValue *value, long long val);
+gint64        gda_value_get_bigint (GdaValue *value);
+void          gda_value_set_bigint (GdaValue *value, gint64 val);
 gconstpointer gda_value_get_binary (GdaValue *value);
 void          gda_value_set_binary (GdaValue *value, gconstpointer val, glong size);
 gboolean      gda_value_get_boolean (GdaValue *value);
@@ -88,7 +94,11 @@ const GdaGeometricPoint *gda_value_get_geometric_point (GdaValue *value);
 void          gda_value_set_geometric_point (GdaValue *value, GdaGeometricPoint *val);
 gint          gda_value_get_integer (GdaValue *value);
 void          gda_value_set_integer (GdaValue *value, gint val);
+const GdaValueList *gda_value_get_list (GdaValue *value);
+void          gda_value_set_list (GdaValue *value, GdaValueList *val);
 void          gda_value_set_null (GdaValue *value);
+const GdaNumeric *gda_value_get_numeric (GdaValue *value);
+void          gda_value_set_numeric (GdaValue *value, GdaNumeric *val);
 gfloat        gda_value_get_single (GdaValue *value);
 void          gda_value_set_single (GdaValue *value, gfloat val);
 gshort        gda_value_get_smallint (GdaValue *value);
@@ -102,7 +112,7 @@ void          gda_value_set_timestamp (GdaValue *value, GdaTimestamp *val);
 gchar         gda_value_get_tinyint (GdaValue *value);
 void          gda_value_set_tinyint (GdaValue *value, gchar val);
 
-gchar        *gda_value_stringify (const GdaValue *value);
+gchar        *gda_value_stringify (GdaValue *value);
 
 G_END_DECLS
 
