@@ -22,8 +22,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <postgres.h>
-#include <catalog/pg_type.h>
+#include <stdlib.h>
+#include <string.h>
 #include "gda-postgres.h"
 
 GdaError *
@@ -33,7 +33,7 @@ gda_postgres_make_error (PGconn *handle)
 
 	error = gda_error_new ();
 	if (handle != NULL) {
-		gda_error_set_description (error, PQerrorMessage(handle));
+		gda_error_set_description (error, PQerrorMessage (handle));
 		gda_error_set_number (error, -1);
 	} else {
 		gda_error_set_description (error, _("NO DESCRIPTION"));
@@ -47,113 +47,63 @@ gda_postgres_make_error (PGconn *handle)
 }
 
 GdaType
-gda_postgres_type_to_gda (Oid postgres_type)
+gda_postgres_type_name_to_gda (GHashTable *h_table, const gchar *name)
 {
-	switch (postgres_type) {
-	case BOOLOID :
-		return GDA_TYPE_BOOLEAN;
-	case BYTEAOID :
-	case CHAROID :
-	case NAMEOID :
-	case TEXTOID :
-	case BPCHAROID :
-	case VARCHAROID :
-		return GDA_TYPE_STRING;
-	case INT8OID :
-		return GDA_TYPE_BIGINT;
-	case INT4OID :
-	case RELTIMEOID :
-		return GDA_TYPE_INTEGER;
-	case INT2OID :
-		return GDA_TYPE_SMALLINT;
-	case FLOAT4OID :
-		return GDA_TYPE_SINGLE;
-	case FLOAT8OID :
-	case NUMERICOID :
-		return GDA_TYPE_DOUBLE;
-	case ABSTIMEOID :
-	case TIMESTAMPOID :
-		return GDA_TYPE_TIMESTAMP;
-	case DATEOID :
-		return GDA_TYPE_DATE;
-	case TIMEOID :
-	case TIMETZOID :
-		return GDA_TYPE_TIME;
-	case VARBITOID :
-		return GDA_TYPE_BINARY;
-	case POINTOID :
-		return GDA_TYPE_GEOMETRIC_POINT;
-	}
+	GdaType *type;
+
+	type = g_hash_table_lookup (h_table, name);
+	if (type)
+		return *type;
 
 	return GDA_TYPE_STRING;
 }
 
-/* Makes a point from a string like "(3.2,5.6)" */
-static GdaGeometricPoint *
-make_point (const gchar *value)
+GdaType
+gda_postgres_type_oid_to_gda (GdaPostgresTypeOid *type_data, gint ntypes, Oid postgres_type)
 {
-	GdaGeometricPoint *point;
+	gint i;
 
-	g_return_val_if_fail (value != NULL, NULL);
-	
-	point = g_new (GdaGeometricPoint, 1);
+	for (i = 0; i < ntypes; i++)
+		if (type_data[i].oid == postgres_type) 
+			break;
+
+	if (type_data[i].oid != postgres_type)
+		return GDA_TYPE_STRING;
+
+	return type_data[i].type;
+}
+
+/* Makes a point from a string like "(3.2,5.6)" */
+static void
+make_point (GdaGeometricPoint *point, const gchar *value)
+{
 	value++;
 	point->x = atof (value);
 	value = strchr (value, ',');
 	value++;
 	point->y = atof (value);
-
-	return point;
-}
-
-static void
-delete_point (GdaGeometricPoint *point)
-{
-	g_return_if_fail (point != NULL);
-	
-	g_free (point);
 }
 
 /* Makes a GdaTime from a string like "12:30:15+01" */
-static GdaTime *
-make_time (const gchar *value)
+static void
+make_time (GdaTime *timegda, const gchar *value)
 {
-	GdaTime *time;
-
-	g_return_val_if_fail (value != NULL, NULL);
-	
-	time = g_new (GdaTime, 1);
-	time->hour = atoi (value);
+	timegda->hour = atoi (value);
 	value += 3;
-	time->minute = atoi (value);
+	timegda->minute = atoi (value);
 	value += 3;
-	time->second = atoi (value);
+	timegda->second = atoi (value);
 	value += 2;
 	if (*value)
-		time->timezone = atoi (value);
+		timegda->timezone = atoi (value);
 	else
-		time->timezone = TIMEZONE_INVALID;
-
-	return time;
-}
-
-static void
-delete_time (GdaTime *time)
-{
-	g_return_if_fail (time != NULL);
-	
-	g_free (time);
+		timegda->timezone = TIMEZONE_INVALID;
 }
 
 /* Makes a GdaTimestamp from a string like "2003-12-13 13:12:01.12+01" */
-static GdaTimestamp *
-make_timestamp (const gchar *value)
+static void
+make_timestamp (GdaTimestamp *timestamp, const gchar *value)
 {
-	GdaTimestamp *timestamp;
-
-	g_return_val_if_fail (value != NULL, NULL);
-	
-	timestamp = g_new (GdaTimestamp, 1);
 	timestamp->year = atoi (value);
 	value += 5;
 	timestamp->month = atoi (value);
@@ -169,16 +119,6 @@ make_timestamp (const gchar *value)
 	timestamp->fraction = atol (value) * 10; // I have only hundredths of second
 	value += 3;
 	timestamp->timezone = atol (value) * 60 * 60;
-
-	return timestamp;
-}
-
-static void
-delete_timestamp (GdaTimestamp *timestamp)
-{
-	g_return_if_fail (timestamp != NULL);
-	
-	g_free (timestamp);
 }
 
 void 
@@ -187,10 +127,11 @@ gda_postgres_set_field_data (GdaField *field, const gchar *fname,
 				gint dbsize, gboolean isNull)
 {
 	GDate *gdate;
-	GdaDate *date;
-	GdaTime *time;
-	GdaTimestamp *timestamp;
-	GdaGeometricPoint *point;
+	GdaDate date;
+	GdaTime timegda;
+	GdaTimestamp timestamp;
+	GdaGeometricPoint point;
+	GdaNumeric numeric;
 	gint scale;
 
 	g_return_if_fail (field != NULL);
@@ -214,39 +155,38 @@ gda_postgres_set_field_data (GdaField *field, const gchar *fname,
 		gda_field_set_gdatype (field, type);
 		gda_field_set_boolean_value (field, 
 				(*value == 't') ? TRUE : FALSE);
-		gda_field_set_actual_size (field, sizeof (gboolean));
 		break;
 	case GDA_TYPE_STRING :
 		gda_field_set_gdatype (field, type);
 		gda_field_set_string_value (field, value);
-		gda_field_set_actual_size (field, strlen (value));
 		break;
 	case GDA_TYPE_BIGINT :
 		gda_field_set_gdatype (field, type);
-		//FIXME: Don't know if atoll() is portable
 		gda_field_set_bigint_value (field, atoll (value));
-		//TODO: conditionally use gint64 based on G_HAVE_GINT64
-		gda_field_set_actual_size (field, sizeof (gint64));
 		break;
 	case GDA_TYPE_INTEGER :
 		gda_field_set_gdatype (field, type);
 		gda_field_set_integer_value (field, atol (value));
-		gda_field_set_actual_size (field, sizeof (gint32));
 		break;
 	case GDA_TYPE_SMALLINT :
 		gda_field_set_gdatype (field, type);
 		gda_field_set_smallint_value (field, atoi (value));
-		gda_field_set_actual_size (field, sizeof (gint16));
 		break;
 	case GDA_TYPE_SINGLE :
 		gda_field_set_gdatype (field, type);
 		gda_field_set_single_value (field, atof (value));
-		gda_field_set_actual_size (field, sizeof (gfloat));
 		break;
 	case GDA_TYPE_DOUBLE :
 		gda_field_set_gdatype (field, type);
 		gda_field_set_double_value (field, atof (value));
-		gda_field_set_actual_size (field, sizeof (gdouble));
+		break;
+	case GDA_TYPE_NUMERIC :
+		numeric.number = g_strdup (value);
+		numeric.decimalPrecision = 0; //FIXME
+		numeric.width = 0; //FIXME
+		gda_field_set_gdatype (field, type);
+		gda_field_set_numeric_value (field, &numeric);
+		g_free (numeric.number);
 		break;
 	case GDA_TYPE_DATE :
 		gda_field_set_gdatype (field, type);
@@ -258,46 +198,96 @@ gda_postgres_set_field_data (GdaField *field, const gchar *fname,
 			g_date_clear (gdate, 1);
 			g_date_set_dmy (gdate, 1, 1, 1);
 		}
-		date = g_new (GdaDate, 1);
-		date->day = g_date_get_day (gdate);
-		date->month = g_date_get_month (gdate);
-		date->year = g_date_get_year (gdate);
-		gda_field_set_date_value (field, date);
-		g_free (date);
+		date.day = g_date_get_day (gdate);
+		date.month = g_date_get_month (gdate);
+		date.year = g_date_get_year (gdate);
+		gda_field_set_date_value (field, &date);
 		g_date_free (gdate);
-		gda_field_set_actual_size (field, sizeof (GdaDate));
 		break;
 	case GDA_TYPE_GEOMETRIC_POINT :
-		point = make_point (value);
-		gda_field_set_geometric_point_value (field, point);
+		make_point (&point, value);
+		gda_field_set_geometric_point_value (field, &point);
 		gda_field_set_gdatype (field, type);
-		delete_point (point);
-		gda_field_set_actual_size (field, sizeof (GdaGeometricPoint));
 		break;
 	case GDA_TYPE_NULL :
 		gda_field_set_gdatype (field, type);
 		gda_field_set_null_value (field);
-		gda_field_set_actual_size (field, 0);
 		break;
 	case GDA_TYPE_TIMESTAMP :
-		timestamp = make_timestamp (value);
-		gda_field_set_timestamp_value (field, timestamp);
+		make_timestamp (&timestamp, value);
+		gda_field_set_timestamp_value (field, &timestamp);
 		gda_field_set_gdatype (field, type);
-		delete_timestamp (timestamp);
-		gda_field_set_actual_size (field, sizeof (GdaTimestamp));
 		break;
 	case GDA_TYPE_TIME :
-		time = make_time (value);
-		gda_field_set_time_value (field, time);
+		make_time (&timegda, value);
+		gda_field_set_time_value (field, &timegda);
 		gda_field_set_gdatype (field, type);
-		delete_time (time);
-		gda_field_set_actual_size (field, sizeof (GdaTime));
 		break;
 	case GDA_TYPE_BINARY : //FIXME
 	default :
 		gda_field_set_string_value (field, value);
 		gda_field_set_gdatype (field, GDA_TYPE_STRING);
-		gda_field_set_actual_size (field, strlen (value));
 	}
 }
 
+const gchar *
+gda_data_type_to_string (GdaType type)
+{
+	gchar *result;
+
+	switch (type) {
+	case GDA_TYPE_NULL :
+		result = _("NULL");
+		break;
+	case GDA_TYPE_BIGINT :
+		result = _("big integer");
+		break;
+	case GDA_TYPE_BINARY :
+		result = _("binary");
+		break;
+	case GDA_TYPE_BOOLEAN :
+		result = _("boolean");
+		break;
+	case GDA_TYPE_DATE :
+		result = _("date");
+		break;
+	case GDA_TYPE_DOUBLE :
+		result = _("double precision");
+		break;
+	case GDA_TYPE_GEOMETRIC_POINT :
+		result = _("geometric point");
+		break;
+	case GDA_TYPE_INTEGER :
+		result = _("integer");
+		break;
+	case GDA_TYPE_LIST :
+		result = _("list of values");
+		break;
+	case GDA_TYPE_NUMERIC :
+		result = _("numeric");
+		break;
+	case GDA_TYPE_SINGLE :
+		result = _("single precision");
+		break;
+	case GDA_TYPE_SMALLINT :
+		result = _("small integer");
+		break;
+	case GDA_TYPE_STRING :
+		result = _("string");
+		break;
+	case GDA_TYPE_TIME :
+		result = _("time");
+		break;
+	case GDA_TYPE_TIMESTAMP :
+		result = _("timestamp");
+		break;
+	case GDA_TYPE_TINYINT :
+		result = _("tiny integer");
+		break;
+	default:
+		result = _("Unknown type");
+	}
+
+	return result;
+}
+
